@@ -139,7 +139,7 @@ our @ISA = qw( Exporter );
 our %EXPORT_TAGS = ( );
 our @EXPORT_OK = ( );
 our @EXPORT = qw( xml2pl pl2xml xml_compare xml_identity );
-our $VERSION = '0.74'; 
+our $VERSION = '0.75'; 
 
 our $COMPRESSION_AVAILABLE;
 
@@ -531,11 +531,11 @@ sub undump {
 
 				$self->{ perldata }{ $address } = $ref if( $address );
 				if( $class ) {
-					unless( int( eval( "\%$class"."::")) ) {
-						# Check class name for nasty stuff...
-						$class =~ m/^[\w-]+(?=::[\w-]+)*$/
-							or die "Refusing to load unsafe class name '$class'\n";
+					# Check class name for nasty stuff...
+					$class =~ m/^[\w-]+(?:::[\w-]+)*$/
+						or die "Refusing to load unsafe class name '$class'\n";
 
+					unless( int( eval( "\%$class"."::")) ) {
 						eval "require $class;";
 						if( $@ ) {
 							warn $@;
@@ -580,11 +580,11 @@ sub undump {
 					}
 				}
 				if( $class ) {
-					unless( int( eval( "\%$class"."::")) ) {
-						# Check class name for nasty stuff...
-						$class =~ m/^[\w-]+(?=::[\w-]+)*$/
-							or die "Refusing to load unsafe class name '$class'\n";
+					# Check class name for nasty stuff...
+					$class =~ m/^[\w-]+(?:::[\w-]+)*$/
+						or die "Refusing to load unsafe class name '$class'\n";
 
+					unless( int( eval( "\%$class"."::")) ) {
 						eval "require $class;";
 						if( $@ ) {
 							warn $@;
@@ -625,11 +625,11 @@ sub undump {
 					}
 				}
 				if( $class ) {
-					unless( int( eval( "\%$class"."::")) ) {
-						# Check class name for nasty stuff...
-						$class =~ m/^[\w-]+(?=::[\w-]+)*$/
-							or die "Refusing to load unsafe class name '$class'\n";
+					# Check class name for nasty stuff...
+					$class =~ m/^[\w-]+(?:::[\w-]+)*$/
+						or die "Refusing to load unsafe class name '$class'\n";
 
+					unless( int( eval( "\%$class"."::")) ) {
 						eval "require $class;";
 						if( $@ ) {
 							warn $@;
